## 0.4.0.20260402 (2026-04-02)

Update most test/lint dependencies ([#15582](https://github.com/python/typeshed/pull/15582))

## 0.4.0.20251008 (2025-10-08)

[stubsabot] Bump flake8-rst-docstrings to 0.4.* ([#14843](https://github.com/python/typeshed/pull/14843))

Release: https://pypi.org/pypi/flake8-rst-docstrings/0.4.0
Homepage: https://github.com/peterjc/flake8-rst-docstrings
Repository: https://github.com/peterjc/flake8-rst-docstrings
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/flake8-rst-docstrings
Diff: https://github.com/peterjc/flake8-rst-docstrings/compare/v0.3.1...v0.4.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `flake8_rst_docstrings.py`.
 - Total lines of Python code added: 32.
 - Total lines of Python code deleted: 36.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 0.3.0.20250425 (2025-04-25)

Mark `flake8-rst-docstrings` as complete ([#13867](https://github.com/python/typeshed/pull/13867))

## 0.3.0.3 (2023-07-20)

Add an upstream_repository field to METADATA.toml ([#10487](https://github.com/python/typeshed/pull/10487))

Closes: #10478

## 0.3.0.2 (2023-05-10)

Add `partial_stub` metadata field ([#10157](https://github.com/python/typeshed/pull/10157))

## 0.3.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` ([#9779](https://github.com/python/typeshed/pull/9779))

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.3.0.0 (2022-11-17)

[stubsabot] Bump flake8-rst-docstrings to 0.3.* ([#9218](https://github.com/python/typeshed/pull/9218))

Release: https://pypi.org/pypi/flake8-rst-docstrings/0.3.0
Homepage: https://github.com/peterjc/flake8-rst-docstrings
Diff: https://github.com/peterjc/flake8-rst-docstrings/compare/v0.2.7...v0.3.0

Stubsabot analysis of the diff between the two releases:
 - 2 public Python files have been added: `tests/RST214/plurals.py`, `tests/RST215/plurals.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `flake8_rst_docstrings.py`.
 - Total lines of Python code added: 38.
 - Total lines of Python code deleted: 54.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 0.2.2 (2022-06-08)

Update flake8-rst-docstrings ([#8033](https://github.com/python/typeshed/pull/8033))

Fixes #8032

Co-authored-by: hauntsaninja <>

## 0.2.1 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible ([#7637](https://github.com/python/typeshed/pull/7637))

## 0.2.0 (2022-01-25)

Add stubs for flake8_rst_docstrings ([#7029](https://github.com/python/typeshed/pull/7029))

